@@ -29,6 +29,7 @@ class Credenciador(object):
 class TipoAutenticacao(object):
     cabecalho_http = 1
     query_string = 2
+    form_urlencode = 3
 
 
 class TipoConexao(object):
@@ -63,6 +64,8 @@ class Credenciais(base.Plugavel):
             self.configuracao_pagamento.atualizar()
         if self.credenciador.tipo == TipoAutenticacao.cabecalho_http:
             return self.por_cabecalho_http()
+        if self.credenciador.tipo == TipoAutenticacao.form_urlencode:
+            return self.por_form_urlencoded()
         if self.credenciador.tipo == TipoAutenticacao.query_string:
             separador = "&" if "?" in url else "?"
             return "{}{}{}".format(url, separador, self.por_query_string())
@@ -77,6 +80,12 @@ class Credenciais(base.Plugavel):
         except AttributeError:
             raise CredenciadorInvalido(u"O credenciador {}.{} não implementa o método obter_credenciais(credenciamento=None).".format(self.credenciador.__module__, self.credenciador.__class__.__name__))
 
+    def por_form_urlencoded(self):
+        try:
+            return {self.credenciador.chave: self.credenciador.obter_credenciais()}
+        except AttributeError:
+            raise CredenciadorInvalido(u"O credenciador {}.{} não implementa o método obter_credenciais(credenciamento=None).".format(self.credenciador.__module__, self.credenciador.__class__.__name__))
+
     def por_cabecalho_http(self, cabecalho="Authorization"):
         try:
             return {cabecalho: self.credenciador.obter_credenciais()}
