@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from urllib import quote_plus
 from xml.etree import ElementTree
 
 
@@ -9,6 +10,10 @@ class Formatador(object):
             return data.strftime("%Y-%m-%d{}%H:%M:%S".format("T" if iso else " "))
         return data.strftime("%Y-%m-%d")
 
+    @classmethod
+    def string_para_url(cls, texto):
+        return quote_plus(unicode(texto))
+
     @classmethod
     def formata_decimal(cls, valor, como_float=False, como_int=False):
         if como_float:
